pub struct Opts {
pub dir_diff: bool,
pub left: PathBuf,
pub right: PathBuf,
pub read_only: bool,
pub dry_run: bool,
pub base: Option<PathBuf>,
pub output: Option<PathBuf>,
}Expand description
Render a partial commit selector for use as a difftool or mergetool.
This can be used to interactively select changes to include as part of a commit, to resolve merge conflicts, or to simply display a diff in a readable way.
Fields
dir_diff: boolInstead of comparing two files, compare two directories recursively.
left: PathBufThe left-hand file to compare (or directory if --dir-diff is passed).
right: PathBufThe right-hand file to compare (or directory if --dir-diff is passed).
read_only: boolDisable all editing controls and do not write the selected commit contents to disk.
dry_run: boolShow what would have been written to disk as part of the commit selection, but do not actually write it.
base: Option<PathBuf>Render the interface as a mergetool instead of a difftool and use this file as the base of a three-way diff as part of resolving merge conflicts.
output: Option<PathBuf>Write the resolved merge conflicts to this file.